@@ -10,9 +10,7 @@ use t::CLI;
 
 use Test::More;
 
-sub run {
-    my @tests = @_;
-
+sub run (@tests) {
     foreach my $t (@tests) {
         my $cli = t::CLI->run( @{ $t->{args} } );
 
